IRAF_image_type — MSUMastro toolbox 0.1 documentation

# IRAF_image_type

`msumastro.header_processing.patchers.` `IRAF_image_type`(image_type)

  Convert MaximDL default image type names to IRAF

  Parameters: | image_type : str Value of the FITS header keyword IMAGETYP; acceptable values are below in Notes.
  Returns: | str IRAF image type (one of ‘BIAS’, ‘DARK’, ‘FLAT’ or ‘LIGHT’)

  Notes

  The MaximDL default is, e.g. ‘Bias Frame’, which IRAF calls ‘BIAS’. Can safely be called with an IRAF-style image_type.